# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/group/v1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from pyinjective.proto.cosmos.group.v1 import types_pb2 as cosmos_dot_group_dot_v1_dot_types__pb2
from pyinjective.proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x63osmos/group/v1/query.proto\x12\x0f\x63osmos.group.v1\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1b\x63osmos/group/v1/types.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x11\x61mino/amino.proto\"2\n\x15QueryGroupInfoRequest\x12\x19\n\x08group_id\x18\x01 \x01(\x04R\x07groupId\"H\n\x16QueryGroupInfoResponse\x12.\n\x04info\x18\x01 \x01(\x0b\x32\x1a.cosmos.group.v1.GroupInfoR\x04info\"Q\n\x1bQueryGroupPolicyInfoRequest\x12\x32\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x07\x61\x64\x64ress\"T\n\x1cQueryGroupPolicyInfoResponse\x12\x34\n\x04info\x18\x01 \x01(\x0b\x32 .cosmos.group.v1.GroupPolicyInfoR\x04info\"}\n\x18QueryGroupMembersRequest\x12\x19\n\x08group_id\x18\x01 \x01(\x04R\x07groupId\x12\x46\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\x9c\x01\n\x19QueryGroupMembersResponse\x12\x36\n\x07members\x18\x01 \x03(\x0b\x32\x1c.cosmos.group.v1.GroupMemberR\x07members\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"\x93\x01\n\x19QueryGroupsByAdminRequest\x12.\n\x05\x61\x64min\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05\x61\x64min\x12\x46\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\x99\x01\n\x1aQueryGroupsByAdminResponse\x12\x32\n\x06groups\x18\x01 \x03(\x0b\x32\x1a.cosmos.group.v1.GroupInfoR\x06groups\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"\x85\x01\n QueryGroupPoliciesByGroupRequest\x12\x19\n\x08group_id\x18\x01 \x01(\x04R\x07groupId\x12\x46\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\xb5\x01\n!QueryGroupPoliciesByGroupResponse\x12G\n\x0egroup_policies\x18\x01 \x03(\x0b\x32 .cosmos.group.v1.GroupPolicyInfoR\rgroupPolicies\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"\x9a\x01\n QueryGroupPoliciesByAdminRequest\x12.\n\x05\x61\x64min\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05\x61\x64min\x12\x46\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\xb5\x01\n!QueryGroupPoliciesByAdminResponse\x12G\n\x0egroup_policies\x18\x01 \x03(\x0b\x32 .cosmos.group.v1.GroupPolicyInfoR\rgroupPolicies\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"7\n\x14QueryProposalRequest\x12\x1f\n\x0bproposal_id\x18\x01 \x01(\x04R\nproposalId\"N\n\x15QueryProposalResponse\x12\x35\n\x08proposal\x18\x01 \x01(\x0b\x32\x19.cosmos.group.v1.ProposalR\x08proposal\"\xa0\x01\n\"QueryProposalsByGroupPolicyRequest\x12\x32\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x07\x61\x64\x64ress\x12\x46\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\xa7\x01\n#QueryProposalsByGroupPolicyResponse\x12\x37\n\tproposals\x18\x01 \x03(\x0b\x32\x19.cosmos.group.v1.ProposalR\tproposals\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"r\n\x1fQueryVoteByProposalVoterRequest\x12\x1f\n\x0bproposal_id\x18\x01 \x01(\x04R\nproposalId\x12.\n\x05voter\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05voter\"M\n QueryVoteByProposalVoterResponse\x12)\n\x04vote\x18\x01 \x01(\x0b\x32\x15.cosmos.group.v1.VoteR\x04vote\"\x86\x01\n\x1bQueryVotesByProposalRequest\x12\x1f\n\x0bproposal_id\x18\x01 \x01(\x04R\nproposalId\x12\x46\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\x94\x01\n\x1cQueryVotesByProposalResponse\x12+\n\x05votes\x18\x01 \x03(\x0b\x32\x15.cosmos.group.v1.VoteR\x05votes\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"\x92\x01\n\x18QueryVotesByVoterRequest\x12.\n\x05voter\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05voter\x12\x46\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\x91\x01\n\x19QueryVotesByVoterResponse\x12+\n\x05votes\x18\x01 \x03(\x0b\x32\x15.cosmos.group.v1.VoteR\x05votes\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"\x98\x01\n\x1aQueryGroupsByMemberRequest\x12\x32\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x07\x61\x64\x64ress\x12\x46\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\x9a\x01\n\x1bQueryGroupsByMemberResponse\x12\x32\n\x06groups\x18\x01 \x03(\x0b\x32\x1a.cosmos.group.v1.GroupInfoR\x06groups\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\":\n\x17QueryTallyResultRequest\x12\x1f\n\x0bproposal_id\x18\x01 \x01(\x04R\nproposalId\"Y\n\x18QueryTallyResultResponse\x12=\n\x05tally\x18\x01 \x01(\x0b\x32\x1c.cosmos.group.v1.TallyResultB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x05tally\"\\\n\x12QueryGroupsRequest\x12\x46\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\x92\x01\n\x13QueryGroupsResponse\x12\x32\n\x06groups\x18\x01 \x03(\x0b\x32\x1a.cosmos.group.v1.GroupInfoR\x06groups\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination2\xfb\x11\n\x05Query\x12\x8c\x01\n\tGroupInfo\x12&.cosmos.group.v1.QueryGroupInfoRequest\x1a\'.cosmos.group.v1.QueryGroupInfoResponse\".\x82\xd3\xe4\x93\x02(\x12&/cosmos/group/v1/group_info/{group_id}\x12\xa4\x01\n\x0fGroupPolicyInfo\x12,.cosmos.group.v1.QueryGroupPolicyInfoRequest\x1a-.cosmos.group.v1.QueryGroupPolicyInfoResponse\"4\x82\xd3\xe4\x93\x02.\x12,/cosmos/group/v1/group_policy_info/{address}\x12\x98\x01\n\x0cGroupMembers\x12).cosmos.group.v1.QueryGroupMembersRequest\x1a*.cosmos.group.v1.QueryGroupMembersResponse\"1\x82\xd3\xe4\x93\x02+\x12)/cosmos/group/v1/group_members/{group_id}\x12\x9a\x01\n\rGroupsByAdmin\x12*.cosmos.group.v1.QueryGroupsByAdminRequest\x1a+.cosmos.group.v1.QueryGroupsByAdminResponse\"0\x82\xd3\xe4\x93\x02*\x12(/cosmos/group/v1/groups_by_admin/{admin}\x12\xba\x01\n\x14GroupPoliciesByGroup\x12\x31.cosmos.group.v1.QueryGroupPoliciesByGroupRequest\x1a\x32.cosmos.group.v1.QueryGroupPoliciesByGroupResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/cosmos/group/v1/group_policies_by_group/{group_id}\x12\xb7\x01\n\x14GroupPoliciesByAdmin\x12\x31.cosmos.group.v1.QueryGroupPoliciesByAdminRequest\x1a\x32.cosmos.group.v1.QueryGroupPoliciesByAdminResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/cosmos/group/v1/group_policies_by_admin/{admin}\x12\x8a\x01\n\x08Proposal\x12%.cosmos.group.v1.QueryProposalRequest\x1a&.cosmos.group.v1.QueryProposalResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/cosmos/group/v1/proposal/{proposal_id}\x12\xc1\x01\n\x16ProposalsByGroupPolicy\x12\x33.cosmos.group.v1.QueryProposalsByGroupPolicyRequest\x1a\x34.cosmos.group.v1.QueryProposalsByGroupPolicyResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/cosmos/group/v1/proposals_by_group_policy/{address}\x12\xc1\x01\n\x13VoteByProposalVoter\x12\x30.cosmos.group.v1.QueryVoteByProposalVoterRequest\x1a\x31.cosmos.group.v1.QueryVoteByProposalVoterResponse\"E\x82\xd3\xe4\x93\x02?\x12=/cosmos/group/v1/vote_by_proposal_voter/{proposal_id}/{voter}\x12\xa8\x01\n\x0fVotesByProposal\x12,.cosmos.group.v1.QueryVotesByProposalRequest\x1a-.cosmos.group.v1.QueryVotesByProposalResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/cosmos/group/v1/votes_by_proposal/{proposal_id}\x12\x96\x01\n\x0cVotesByVoter\x12).cosmos.group.v1.QueryVotesByVoterRequest\x1a*.cosmos.group.v1.QueryVotesByVoterResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/cosmos/group/v1/votes_by_voter/{voter}\x12\xa0\x01\n\x0eGroupsByMember\x12+.cosmos.group.v1.QueryGroupsByMemberRequest\x1a,.cosmos.group.v1.QueryGroupsByMemberResponse\"3\x82\xd3\xe4\x93\x02-\x12+/cosmos/group/v1/groups_by_member/{address}\x12\x9a\x01\n\x0bTallyResult\x12(.cosmos.group.v1.QueryTallyResultRequest\x1a).cosmos.group.v1.QueryTallyResultResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./cosmos/group/v1/proposals/{proposal_id}/tally\x12t\n\x06Groups\x12#.cosmos.group.v1.QueryGroupsRequest\x1a$.cosmos.group.v1.QueryGroupsResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/cosmos/group/v1/groupsB\xa5\x01\n\x13\x63om.cosmos.group.v1B\nQueryProtoP\x01Z$github.com/cosmos/cosmos-sdk/x/group\xa2\x02\x03\x43GX\xaa\x02\x0f\x43osmos.Group.V1\xca\x02\x0f\x43osmos\\Group\\V1\xe2\x02\x1b\x43osmos\\Group\\V1\\GPBMetadata\xea\x02\x11\x43osmos::Group::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.group.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023com.cosmos.group.v1B\nQueryProtoP\001Z$github.com/cosmos/cosmos-sdk/x/group\242\002\003CGX\252\002\017Cosmos.Group.V1\312\002\017Cosmos\\Group\\V1\342\002\033Cosmos\\Group\\V1\\GPBMetadata\352\002\021Cosmos::Group::V1'
  _globals['_QUERYGROUPPOLICYINFOREQUEST'].fields_by_name['address']._loaded_options = None
  _globals['_QUERYGROUPPOLICYINFOREQUEST'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYGROUPSBYADMINREQUEST'].fields_by_name['admin']._loaded_options = None
  _globals['_QUERYGROUPSBYADMINREQUEST'].fields_by_name['admin']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYGROUPPOLICIESBYADMINREQUEST'].fields_by_name['admin']._loaded_options = None
  _globals['_QUERYGROUPPOLICIESBYADMINREQUEST'].fields_by_name['admin']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYPROPOSALSBYGROUPPOLICYREQUEST'].fields_by_name['address']._loaded_options = None
  _globals['_QUERYPROPOSALSBYGROUPPOLICYREQUEST'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYVOTEBYPROPOSALVOTERREQUEST'].fields_by_name['voter']._loaded_options = None
  _globals['_QUERYVOTEBYPROPOSALVOTERREQUEST'].fields_by_name['voter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYVOTESBYVOTERREQUEST'].fields_by_name['voter']._loaded_options = None
  _globals['_QUERYVOTESBYVOTERREQUEST'].fields_by_name['voter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYGROUPSBYMEMBERREQUEST'].fields_by_name['address']._loaded_options = None
  _globals['_QUERYGROUPSBYMEMBERREQUEST'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYTALLYRESULTRESPONSE'].fields_by_name['tally']._loaded_options = None
  _globals['_QUERYTALLYRESULTRESPONSE'].fields_by_name['tally']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERY'].methods_by_name['GroupInfo']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GroupInfo']._serialized_options = b'\202\323\344\223\002(\022&/cosmos/group/v1/group_info/{group_id}'
  _globals['_QUERY'].methods_by_name['GroupPolicyInfo']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GroupPolicyInfo']._serialized_options = b'\202\323\344\223\002.\022,/cosmos/group/v1/group_policy_info/{address}'
  _globals['_QUERY'].methods_by_name['GroupMembers']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GroupMembers']._serialized_options = b'\202\323\344\223\002+\022)/cosmos/group/v1/group_members/{group_id}'
  _globals['_QUERY'].methods_by_name['GroupsByAdmin']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GroupsByAdmin']._serialized_options = b'\202\323\344\223\002*\022(/cosmos/group/v1/groups_by_admin/{admin}'
  _globals['_QUERY'].methods_by_name['GroupPoliciesByGroup']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GroupPoliciesByGroup']._serialized_options = b'\202\323\344\223\0025\0223/cosmos/group/v1/group_policies_by_group/{group_id}'
  _globals['_QUERY'].methods_by_name['GroupPoliciesByAdmin']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GroupPoliciesByAdmin']._serialized_options = b'\202\323\344\223\0022\0220/cosmos/group/v1/group_policies_by_admin/{admin}'
  _globals['_QUERY'].methods_by_name['Proposal']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Proposal']._serialized_options = b'\202\323\344\223\002)\022\'/cosmos/group/v1/proposal/{proposal_id}'
  _globals['_QUERY'].methods_by_name['ProposalsByGroupPolicy']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ProposalsByGroupPolicy']._serialized_options = b'\202\323\344\223\0026\0224/cosmos/group/v1/proposals_by_group_policy/{address}'
  _globals['_QUERY'].methods_by_name['VoteByProposalVoter']._loaded_options = None
  _globals['_QUERY'].methods_by_name['VoteByProposalVoter']._serialized_options = b'\202\323\344\223\002?\022=/cosmos/group/v1/vote_by_proposal_voter/{proposal_id}/{voter}'
  _globals['_QUERY'].methods_by_name['VotesByProposal']._loaded_options = None
  _globals['_QUERY'].methods_by_name['VotesByProposal']._serialized_options = b'\202\323\344\223\0022\0220/cosmos/group/v1/votes_by_proposal/{proposal_id}'
  _globals['_QUERY'].methods_by_name['VotesByVoter']._loaded_options = None
  _globals['_QUERY'].methods_by_name['VotesByVoter']._serialized_options = b'\202\323\344\223\002)\022\'/cosmos/group/v1/votes_by_voter/{voter}'
  _globals['_QUERY'].methods_by_name['GroupsByMember']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GroupsByMember']._serialized_options = b'\202\323\344\223\002-\022+/cosmos/group/v1/groups_by_member/{address}'
  _globals['_QUERY'].methods_by_name['TallyResult']._loaded_options = None
  _globals['_QUERY'].methods_by_name['TallyResult']._serialized_options = b'\202\323\344\223\0020\022./cosmos/group/v1/proposals/{proposal_id}/tally'
  _globals['_QUERY'].methods_by_name['Groups']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Groups']._serialized_options = b'\202\323\344\223\002\031\022\027/cosmos/group/v1/groups'
  _globals['_QUERYGROUPINFOREQUEST']._serialized_start=219
  _globals['_QUERYGROUPINFOREQUEST']._serialized_end=269
  _globals['_QUERYGROUPINFORESPONSE']._serialized_start=271
  _globals['_QUERYGROUPINFORESPONSE']._serialized_end=343
  _globals['_QUERYGROUPPOLICYINFOREQUEST']._serialized_start=345
  _globals['_QUERYGROUPPOLICYINFOREQUEST']._serialized_end=426
  _globals['_QUERYGROUPPOLICYINFORESPONSE']._serialized_start=428
  _globals['_QUERYGROUPPOLICYINFORESPONSE']._serialized_end=512
  _globals['_QUERYGROUPMEMBERSREQUEST']._serialized_start=514
  _globals['_QUERYGROUPMEMBERSREQUEST']._serialized_end=639
  _globals['_QUERYGROUPMEMBERSRESPONSE']._serialized_start=642
  _globals['_QUERYGROUPMEMBERSRESPONSE']._serialized_end=798
  _globals['_QUERYGROUPSBYADMINREQUEST']._serialized_start=801
  _globals['_QUERYGROUPSBYADMINREQUEST']._serialized_end=948
  _globals['_QUERYGROUPSBYADMINRESPONSE']._serialized_start=951
  _globals['_QUERYGROUPSBYADMINRESPONSE']._serialized_end=1104
  _globals['_QUERYGROUPPOLICIESBYGROUPREQUEST']._serialized_start=1107
  _globals['_QUERYGROUPPOLICIESBYGROUPREQUEST']._serialized_end=1240
  _globals['_QUERYGROUPPOLICIESBYGROUPRESPONSE']._serialized_start=1243
  _globals['_QUERYGROUPPOLICIESBYGROUPRESPONSE']._serialized_end=1424
  _globals['_QUERYGROUPPOLICIESBYADMINREQUEST']._serialized_start=1427
  _globals['_QUERYGROUPPOLICIESBYADMINREQUEST']._serialized_end=1581
  _globals['_QUERYGROUPPOLICIESBYADMINRESPONSE']._serialized_start=1584
  _globals['_QUERYGROUPPOLICIESBYADMINRESPONSE']._serialized_end=1765
  _globals['_QUERYPROPOSALREQUEST']._serialized_start=1767
  _globals['_QUERYPROPOSALREQUEST']._serialized_end=1822
  _globals['_QUERYPROPOSALRESPONSE']._serialized_start=1824
  _globals['_QUERYPROPOSALRESPONSE']._serialized_end=1902
  _globals['_QUERYPROPOSALSBYGROUPPOLICYREQUEST']._serialized_start=1905
  _globals['_QUERYPROPOSALSBYGROUPPOLICYREQUEST']._serialized_end=2065
  _globals['_QUERYPROPOSALSBYGROUPPOLICYRESPONSE']._serialized_start=2068
  _globals['_QUERYPROPOSALSBYGROUPPOLICYRESPONSE']._serialized_end=2235
  _globals['_QUERYVOTEBYPROPOSALVOTERREQUEST']._serialized_start=2237
  _globals['_QUERYVOTEBYPROPOSALVOTERREQUEST']._serialized_end=2351
  _globals['_QUERYVOTEBYPROPOSALVOTERRESPONSE']._serialized_start=2353
  _globals['_QUERYVOTEBYPROPOSALVOTERRESPONSE']._serialized_end=2430
  _globals['_QUERYVOTESBYPROPOSALREQUEST']._serialized_start=2433
  _globals['_QUERYVOTESBYPROPOSALREQUEST']._serialized_end=2567
  _globals['_QUERYVOTESBYPROPOSALRESPONSE']._serialized_start=2570
  _globals['_QUERYVOTESBYPROPOSALRESPONSE']._serialized_end=2718
  _globals['_QUERYVOTESBYVOTERREQUEST']._serialized_start=2721
  _globals['_QUERYVOTESBYVOTERREQUEST']._serialized_end=2867
  _globals['_QUERYVOTESBYVOTERRESPONSE']._serialized_start=2870
  _globals['_QUERYVOTESBYVOTERRESPONSE']._serialized_end=3015
  _globals['_QUERYGROUPSBYMEMBERREQUEST']._serialized_start=3018
  _globals['_QUERYGROUPSBYMEMBERREQUEST']._serialized_end=3170
  _globals['_QUERYGROUPSBYMEMBERRESPONSE']._serialized_start=3173
  _globals['_QUERYGROUPSBYMEMBERRESPONSE']._serialized_end=3327
  _globals['_QUERYTALLYRESULTREQUEST']._serialized_start=3329
  _globals['_QUERYTALLYRESULTREQUEST']._serialized_end=3387
  _globals['_QUERYTALLYRESULTRESPONSE']._serialized_start=3389
  _globals['_QUERYTALLYRESULTRESPONSE']._serialized_end=3478
  _globals['_QUERYGROUPSREQUEST']._serialized_start=3480
  _globals['_QUERYGROUPSREQUEST']._serialized_end=3572
  _globals['_QUERYGROUPSRESPONSE']._serialized_start=3575
  _globals['_QUERYGROUPSRESPONSE']._serialized_end=3721
  _globals['_QUERY']._serialized_start=3724
  _globals['_QUERY']._serialized_end=6023
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/wasmx/v1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.injective.wasmx.v1 import wasmx_pb2 as injective_dot_wasmx_dot_v1_dot_wasmx__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n injective/wasmx/v1/genesis.proto\x12\x12injective.wasmx.v1\x1a\x1einjective/wasmx/v1/wasmx.proto\x1a\x14gogoproto/gogo.proto\"\x92\x01\n\x1dRegisteredContractWithAddress\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12W\n\x13registered_contract\x18\x02 \x01(\x0b\x32&.injective.wasmx.v1.RegisteredContractR\x12registeredContract\"\xb4\x01\n\x0cGenesisState\x12\x38\n\x06params\x18\x01 \x01(\x0b\x32\x1a.injective.wasmx.v1.ParamsB\x04\xc8\xde\x1f\x00R\x06params\x12j\n\x14registered_contracts\x18\x02 \x03(\x0b\x32\x31.injective.wasmx.v1.RegisteredContractWithAddressB\x04\xc8\xde\x1f\x00R\x13registeredContractsB\xdd\x01\n\x16\x63om.injective.wasmx.v1B\x0cGenesisProtoP\x01ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/wasmx/types\xa2\x02\x03IWX\xaa\x02\x12Injective.Wasmx.V1\xca\x02\x12Injective\\Wasmx\\V1\xe2\x02\x1eInjective\\Wasmx\\V1\\GPBMetadata\xea\x02\x14Injective::Wasmx::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.wasmx.v1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.injective.wasmx.v1B\014GenesisProtoP\001ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/wasmx/types\242\002\003IWX\252\002\022Injective.Wasmx.V1\312\002\022Injective\\Wasmx\\V1\342\002\036Injective\\Wasmx\\V1\\GPBMetadata\352\002\024Injective::Wasmx::V1'
  _globals['_GENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['registered_contracts']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['registered_contracts']._serialized_options = b'\310\336\037\000'
  _globals['_REGISTEREDCONTRACTWITHADDRESS']._serialized_start=111
  _globals['_REGISTEREDCONTRACTWITHADDRESS']._serialized_end=257
  _globals['_GENESISSTATE']._serialized_start=260
  _globals['_GENESISSTATE']._serialized_end=440
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/evm/v1/params.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.injective.evm.v1 import chain_config_pb2 as injective_dot_evm_dot_v1_dot_chain__config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dinjective/evm/v1/params.proto\x12\x10injective.evm.v1\x1a\x14gogoproto/gogo.proto\x1a#injective/evm/v1/chain_config.proto\"\xc9\x03\n\x06Params\x12\x31\n\tevm_denom\x18\x01 \x01(\tB\x14\xf2\xde\x1f\x10yaml:\"evm_denom\"R\x08\x65vmDenom\x12=\n\renable_create\x18\x02 \x01(\x08\x42\x18\xf2\xde\x1f\x14yaml:\"enable_create\"R\x0c\x65nableCreate\x12\x37\n\x0b\x65nable_call\x18\x03 \x01(\x08\x42\x16\xf2\xde\x1f\x12yaml:\"enable_call\"R\nenableCall\x12\x41\n\nextra_eips\x18\x04 \x03(\x03\x42\"\xe2\xde\x1f\tExtraEIPs\xf2\xde\x1f\x11yaml:\"extra_eips\"R\textraEips\x12\x46\n\x0c\x63hain_config\x18\x05 \x01(\x0b\x32\x1d.injective.evm.v1.ChainConfigB\x04\xc8\xde\x1f\x00R\x0b\x63hainConfig\x12\x32\n\x15\x61llow_unprotected_txs\x18\x06 \x01(\x08R\x13\x61llowUnprotectedTxs\x12\x31\n\x14\x61uthorized_deployers\x18\x07 \x03(\tR\x13\x61uthorizedDeployers\x12\"\n\x0cpermissioned\x18\x08 \x01(\x08R\x0cpermissionedB\xd0\x01\n\x14\x63om.injective.evm.v1B\x0bParamsProtoP\x01ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/evm/types\xa2\x02\x03IEX\xaa\x02\x10Injective.Evm.V1\xca\x02\x10Injective\\Evm\\V1\xe2\x02\x1cInjective\\Evm\\V1\\GPBMetadata\xea\x02\x12Injective::Evm::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.evm.v1.params_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.injective.evm.v1B\013ParamsProtoP\001ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/evm/types\242\002\003IEX\252\002\020Injective.Evm.V1\312\002\020Injective\\Evm\\V1\342\002\034Injective\\Evm\\V1\\GPBMetadata\352\002\022Injective::Evm::V1'
  _globals['_PARAMS'].fields_by_name['evm_denom']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['evm_denom']._serialized_options = b'\362\336\037\020yaml:\"evm_denom\"'
  _globals['_PARAMS'].fields_by_name['enable_create']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['enable_create']._serialized_options = b'\362\336\037\024yaml:\"enable_create\"'
  _globals['_PARAMS'].fields_by_name['enable_call']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['enable_call']._serialized_options = b'\362\336\037\022yaml:\"enable_call\"'
  _globals['_PARAMS'].fields_by_name['extra_eips']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['extra_eips']._serialized_options = b'\342\336\037\tExtraEIPs\362\336\037\021yaml:\"extra_eips\"'
  _globals['_PARAMS'].fields_by_name['chain_config']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['chain_config']._serialized_options = b'\310\336\037\000'
  _globals['_PARAMS']._serialized_start=111
  _globals['_PARAMS']._serialized_end=568
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/auction/v1beta1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.injective.auction.v1beta1 import auction_pb2 as injective_dot_auction_dot_v1beta1_dot_auction__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'injective/auction/v1beta1/genesis.proto\x12\x19injective.auction.v1beta1\x1a\'injective/auction/v1beta1/auction.proto\x1a\x14gogoproto/gogo.proto\"\xcd\x02\n\x0cGenesisState\x12?\n\x06params\x18\x01 \x01(\x0b\x32!.injective.auction.v1beta1.ParamsB\x04\xc8\xde\x1f\x00R\x06params\x12#\n\rauction_round\x18\x02 \x01(\x04R\x0c\x61uctionRound\x12?\n\x0bhighest_bid\x18\x03 \x01(\x0b\x32\x1e.injective.auction.v1beta1.BidR\nhighestBid\x12\x38\n\x18\x61uction_ending_timestamp\x18\x04 \x01(\x03R\x16\x61uctionEndingTimestamp\x12\\\n\x13last_auction_result\x18\x05 \x01(\x0b\x32,.injective.auction.v1beta1.LastAuctionResultR\x11lastAuctionResultB\x82\x02\n\x1d\x63om.injective.auction.v1beta1B\x0cGenesisProtoP\x01ZMgithub.com/InjectiveLabs/injective-core/injective-chain/modules/auction/types\xa2\x02\x03IAX\xaa\x02\x19Injective.Auction.V1beta1\xca\x02\x19Injective\\Auction\\V1beta1\xe2\x02%Injective\\Auction\\V1beta1\\GPBMetadata\xea\x02\x1bInjective::Auction::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.auction.v1beta1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035com.injective.auction.v1beta1B\014GenesisProtoP\001ZMgithub.com/InjectiveLabs/injective-core/injective-chain/modules/auction/types\242\002\003IAX\252\002\031Injective.Auction.V1beta1\312\002\031Injective\\Auction\\V1beta1\342\002%Injective\\Auction\\V1beta1\\GPBMetadata\352\002\033Injective::Auction::V1beta1'
  _globals['_GENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE']._serialized_start=134
  _globals['_GENESISSTATE']._serialized_end=467
# @@protoc_insertion_point(module_scope)
